package fitconnect.api.problems;

import fitconnect.api.schema.FitConnectSchemaScopes;
import org.zalando.problem.StatusType;
import org.zalando.problem.ThrowableProblem;

import java.net.URI;
import java.util.Collections;
import java.util.Map;

public class FitConnectProblem extends ThrowableProblem {

    private static final long serialVersionUID = 1L;

    private final URI type;

    private final String title;

    private final StatusType status;

    private final String detail;

    private final URI instance;

    private final String issue;

    protected FitConnectProblem(URI type, String title, StatusType status) {
        this(type, title, status, null, null, null);
    }

    protected FitConnectProblem(URI type, String title, StatusType status, String detail, URI instance, String issue) {
        this.type = type;
        this.title = title;
        this.status = status;
        this.detail = detail;
        this.instance = instance;
        this.issue = issue;
    }

    public static URI makeProblemURI(String problemName) {
        return URI.create(FitConnectSchemaScopes.PROBLEMS_BASE_URI + problemName);
    }

    @Override
    public URI getType() {
        return type;
    }

    @Override
    public String getTitle() {
        return title;
    }

    @Override
    public StatusType getStatus() {
        return status;
    }

    @Override
    public String getDetail() {
        return detail;
    }

    @Override
    public URI getInstance() {
        return instance;
    }

    @Override
    public Map<String, Object> getParameters() {
        return issue == null ? Collections.emptyMap() : Map.of("issue", issue);
    }
}
